@@ -1,6 +1,6 @@
 summary.LogConcDEAD <- function(object,...)
   {
-niter <- x$NumberOfEvaluations[1]
+niter <- object$NumberOfEvaluations[1]
 if (niter==-1) errormessage <- "allocation error"
 else if (niter==-2) errormessage <- "improper space dimension"
 else if (niter==-3) errormessage <- "sigma returns an improper value"
@@ -13,9 +13,9 @@ else if (niter==-12) errormessage <- "Result may not provide the true optimum"
 else if (niter==-13) errormessage <- "Result may be inaccurate in view of a point"
 else if (niter==-14) errormessage <- "Result may be inaccurate in view of a function value"
 
-if(niter>0) cat("\n Log MLE at observations: \n", (x$logMLE),
-    "\n\n Number of Iterations: ",x$NumberOfEvaluations[1],
-    "\n\n Number of Function Evaluations: ",x$NumberOfEvaluations[2],
+if(niter>0) cat("\n Log MLE at observations: \n", (object$logMLE),
+    "\n\n Number of Iterations: ",object$NumberOfEvaluations[1],
+    "\n\n Number of Function Evaluations: ",object$NumberOfEvaluations[2],
     fill=10)
 else cat("SolvOpt error: ",errormessage, "\n")
 }
