@@ -29,15 +29,12 @@ void renormalise(double y[])
   double sum;
   int inhull;
   double absdetA;
-  int *supporting;
-  /* int count=0; */
   double logintegral;
 
   allpoints = Calloc((npoints)*(dim + 1),double);
   A = Calloc((dim)*(dim),double);
   z = Calloc(dim,double);
   zprod = Calloc(dim,double);
-  supporting = Calloc(npoints,int);
      
   yminimum = ymin(y,truepoints) - 1.0; 
   totaldim=dim+1; 
@@ -114,15 +111,12 @@ void renormalise(double y[])
       }
     }
 
-
-
    Free(allpoints);
    Free(A);
    Free(z);
    Free(zprod);
    Free(outpoints);
-   Free(supporting);
- 
+  
    logintegral = log(integral);
    for (i=0; i<truepoints; i++) y[i]-=logintegral ;
   }
